#!/bin/sh

#  Hotfix_Datatier
#  Version 1.1.1
#  Copyright (c) 2003-2005 by SAS Institute Inc., Cary, NC 27513
#  Usage: Hotfix_Datatier
#
#  This script is used to apply a SAS Solutions hotfix  
#  to the data tier configuration.

#  DO NOT EDIT ANY ITEM IN THIS FILE. 

clear
echo "SAS Solutions for AIX - Datatier Hotfix"
echo "---------------------------------------"
echo

# Initialize hotfix environment
while read prop junk
do
   if [ "$prop" != \# -a "$prop" ]
   then
       export $prop
   fi
done<hotfixEnv.properties

echo Solutions Hotfix \# : $FIX_NUM
echo Hotfix Type        : $FIX_TYPE
echo Products Affected  : $PRODUCTS
echo Build Date         : $BLDDATE
echo -----------------------------
echo

export TOOLKIT=$PWD
export WORKDIR=$PWD/workdir

if [ ! -e $WORKDIR ]
then
    mkdir $WORKDIR
fi

cd $WORKDIR
echo
echo ==\> Checking Hotfix History
if [ -e $SASCONFIG/HISTORY.MF ]
then
    java -cp $TOOLKIT/lib/sas.solutions.utils.hotfix.jar MaxHotFix $SASCONFIG/HISTORY.MF $FIX_TYPE $FIX_NUM
    while read prop junk
    do
       if [ "$prop" != \# -a "$prop" ]
       then
           export $prop
       fi
    done<_envvar.properties	
fi

cd $TOOLKIT

# Update history file. Use the format:
#    java History history-file-loc tier hotfix-name product version bld-date
# Example:
#    java History $SASCONFIG/HISTORY.MF Data x1SLNS2 All x.1 20050805
echo ==\> Updating Hotfix History
java -cp $TOOLKIT/lib/sas.solutions.utils.hotfix.jar History $SASCONFIG/HISTORY.MF Data $FIX_TYPE$FIX_NUM $PRODUCTS $SOL_VERSION $BLDDATE
if [ "$?" -gt 0 ] 
then
    echo
    echo This SAS Solutions hotfix has already been applied to this machine. If you feel that 
    echo this is an error, please contact SAS Technical Support.
    echo
    echo "Press return to continue. \c"
    read junk
    exit
fi

rm -f $WORKDIR/*
cp -f $SASCONFIG/soltnsdata.properties $WORKDIR
cp -f $SASCONFIG/configuration.properties $WORKDIR
cp -f $TOOLKIT/src/*.orig $WORKDIR
cp -f $TOOLKIT/src/*.xml $WORKDIR
cp -f $TOOLKIT/src/*.MF $WORKDIR

cd $WORKDIR

# ## Not needed any more for AIX??
# java -cp $TOOLKIT/lib/sas.solutions.utils.hotfix.jar SearchReplace "\\\\\\\\" "\\\\" soltnsdata.properties

echo
echo ==\> Generating shell scripts
echo
java -cp $TOOLKIT/lib/stringReplace.jar com.sas.apps.javaconf.JavaConf datatier.xml generate_scripts
rm -f $WORKDIR/deployDataHotfix.sh.orig
mv -f deployDataHotfix.sh deployDataHotfix.sh.orig
java -cp $TOOLKIT/lib/stringReplace.jar com.sas.apps.javaconf.JavaConf service.xml generate_scripts

chmod +x deployDataHotfix.sh

echo
echo ==\> Applying Hotfix
echo
./deployDataHotfix.sh > $TOOLKIT/logs/deployDataHotfix.log

cd $TOOLKIT

echo The SAS Solutions hotfix for the data tier has been applied to this machine.
echo
echo "Press return to continue. \c"
read junk

